@@ -25,7 +25,7 @@ __version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"
 import os
 import pickle
 
-version = "0.8"
+version = "0.9"
 
 try:
     from glib import get_user_config_dir
@@ -59,6 +59,7 @@ class Config:
 	self.id=id
 
 	self.size = (2,2)
+	self.themebgsize = 96
 	self.iconsize = 64
 #	self.iconspace = 42	# For 4 icons (height)
 	self.iconspace = 36	# For 8 icons (width)
@@ -66,6 +67,8 @@ class Config:
 	self.indiv=True
 	self.longpress=False
 	self.animate=True
+	self.nobg=False
+	self.themebg=False
 
 	self.maxsz=(8,4)
 
@@ -99,6 +102,18 @@ class Config:
     def getAnimate(self):
 	return(self.animate)
 
+    def setNoBg(self, nobg):
+	self.nobg=nobg
+
+    def getNoBg(self):
+	return(self.nobg)
+
+    def setThemeBg(self, themebg):
+	self.themebg=themebg
+
+    def getThemeBg(self):
+	return(self.themebg)
+
     def setApps(self, aps):
 	""" apps is a dictionary of (x,y)=>appname """
 	self.apps=aps
@@ -122,7 +137,7 @@ class Config:
 
 	if dt==None:
 	    dt={
-		'version':  4,
+		'version':  6,
 		'data':	{},
 		}
 
@@ -132,6 +147,8 @@ class Config:
 	    'indiv':	    self.getIndiv(),
 	    'longpress':    self.getLongpress(),
 	    'animate':	    self.getAnimate(),
+	    'nobg':	    self.getNoBg(),
+	    'themebg':	    self.getThemeBg(),
 	    }
 
 	fn=get_config_fn()
@@ -175,6 +192,22 @@ class Config:
 
 	return(dt)
 
+    def parse_v4(self, dt):
+	dt['version']=5
+
+	for i in dt['data']:
+	    dt['data'][i]['nobg']=False
+
+	return(dt)
+
+    def parse_v5(self, dt):
+	dt['version']=6
+
+	for i in dt['data']:
+	    dt['data'][i]['themebg']=False
+
+	return(dt)
+
     def load_all(self):
 	fn=get_config_fn()
 
@@ -195,6 +228,12 @@ class Config:
 
 		if ret['version']==3:
 		    ret=parse_v3(ret)
+
+		if ret['version']==4:
+		    ret=parse_v4(ret)
+
+		if ret['version']==5:
+		    ret=parse_v5(ret)
 	except:
 	    ret=None
 
@@ -217,6 +256,8 @@ class Config:
 	self.setIndiv(dt['indiv'])
 	self.setLongpress(dt['longpress'])
 	self.setAnimate(dt['animate'])
+	self.setNoBg(dt['nobg'])
+	self.setThemeBg(dt['themebg'])
 
     def check_init(self):
 	if self.id==None:
